@@ -212,10 +212,13 @@ mod tests {
             Type::Redox,
             Type::Alpaquita,
             Type::Alpine,
+            Type::ALTLinux,
             Type::Amazon,
             Type::Android,
+            Type::AOSC,
             Type::Arch,
             Type::Artix,
+            Type::Bluefin,
             Type::CachyOS,
             Type::CentOS,
             Type::Debian,
@@ -281,6 +284,14 @@ mod tests {
                 },
                 "Linux 2.3.4 [unknown bitness]",
             ),
+            (
+                Info {
+                    os_type: Type::AOSC,
+                    version: Version::Semantic(12, 1, 3),
+                    ..Default::default()
+                },
+                "AOSC OS 12.1.3 [unknown bitness]",
+            ),
             (
                 Info {
                     os_type: Type::Arch,
