@@ -1,4 +1,4 @@
-// spell-checker:ignore sles
+// spell-checker:ignore sles, AOSCOS
 
 use std::{fmt, fs::File, io::Read, path::Path};
 
@@ -93,27 +93,37 @@ static DISTRIBUTIONS: [ReleaseInfo; 6] = [
                     "almalinux" => Some(Type::AlmaLinux),
                     "alpaquita" => Some(Type::Alpaquita),
                     "alpine" => Some(Type::Alpine),
+                    "altlinux" => Some(Type::ALTLinux),
                     "amzn" => Some(Type::Amazon),
                     //"antergos" => Antergos
-                    //"aosc" => AOSC
+                    "aosc" => Some(Type::AOSC),
                     "arch" => Some(Type::Arch),
                     "archarm" => Some(Type::Arch),
                     "artix" => Some(Type::Artix),
+                    "bluefin" => Some(Type::Bluefin),
                     "cachyos" => Some(Type::CachyOS),
                     "centos" => Some(Type::CentOS),
                     //"clear-linux-os" => ClearLinuxOS
                     //"clearos" => ClearOS
                     //"coreos"
                     //"cumulus-linux" => Cumulus
-                    "debian" => Some(Type::Debian),
+                    "debian" => {
+                        // Check if it's actually Raspberry Pi OS
+                        if std::path::Path::new("/etc/rpi-issue").exists() {
+                            Some(Type::Raspbian)
+                        } else {
+                            Some(Type::Debian)
+                        }
+                    }
                     //"devuan" => Devuan
-                    //"elementary" => Elementary
+                    "elementary" => Some(Type::Elementary),
                     "fedora" => Some(Type::Fedora),
                     //"gentoo" => Gentoo
                     //"ios_xr" => ios_xr
                     "kali" => Some(Type::Kali),
                     //"mageia" => Mageia
                     //"manjaro" => Manjaro
+                    "manjaro-arm" => Some(Type::Manjaro),
                     "linuxmint" => Some(Type::Mint),
                     "mariner" => Some(Type::Mariner),
                     //"nexus" => Nexus
@@ -142,6 +152,7 @@ static DISTRIBUTIONS: [ReleaseInfo; 6] = [
                     "ultramarine" => Some(Type::Ultramarine),
                     //"virtuozzo" => Virtuozzo
                     "void" => Some(Type::Void),
+                    "zorin" => Some(Type::Zorin),
                     //"XCP-ng" => xcp-ng
                     //"xenenterprise" => xcp-ng
                     //"xenserver" => xcp-ng
@@ -249,6 +260,17 @@ mod tests {
         assert_eq!(info.codename, None);
     }
 
+    #[test]
+    fn alt_p11_os_release() {
+        let root = "src/linux/tests/ALTLinux_p11";
+
+        let info = retrieve(&DISTRIBUTIONS, root).unwrap();
+        assert_eq!(info.os_type(), Type::ALTLinux);
+        assert_eq!(info.version, Version::Semantic(11, 0, 0));
+        assert_eq!(info.edition, None);
+        assert_eq!(info.codename, None);
+    }
+
     #[test]
     fn amazon_1_os_release() {
         let root = "src/linux/tests/Amazon_1";
@@ -271,6 +293,17 @@ mod tests {
         assert_eq!(info.codename, None);
     }
 
+    #[test]
+    fn aosc_os_release() {
+        let root = "src/linux/tests/AOSCOS";
+
+        let info = retrieve(&DISTRIBUTIONS, root).unwrap();
+        assert_eq!(info.os_type(), Type::AOSC);
+        assert_eq!(info.version, Version::Semantic(12, 1, 3));
+        assert_eq!(info.edition, None);
+        assert_eq!(info.codename, None);
+    }
+
     #[test]
     fn arch_os_release() {
         let root = "src/linux/tests/Arch";
@@ -304,6 +337,17 @@ mod tests {
         assert_eq!(info.codename, None);
     }
 
+    #[test]
+    fn bluefin_os_release() {
+        let root = "src/linux/tests/Bluefin";
+
+        let info = retrieve(&DISTRIBUTIONS, root).unwrap();
+        assert_eq!(info.os_type(), Type::Bluefin);
+        assert_eq!(info.version, Version::Semantic(41, 0, 0));
+        assert_eq!(info.edition, None);
+        assert_eq!(info.codename, None);
+    }
+
     #[test]
     fn centos_7_os_release() {
         let root = "src/linux/tests/CentOS_7";
@@ -414,6 +458,17 @@ mod tests {
         assert_eq!(info.codename, None);
     }
 
+    #[test]
+    fn manjaro_arm_release() {
+        let root = "src/linux/tests/ManjaroArm";
+
+        let info = retrieve(&DISTRIBUTIONS, root).unwrap();
+        assert_eq!(info.os_type(), Type::Manjaro);
+        assert_eq!(info.version, Version::Unknown);
+        assert_eq!(info.edition, None);
+        assert_eq!(info.codename, None);
+    }
+
     #[test]
     fn mariner_release() {
         let root = "src/linux/tests/Mariner";
